Triggers = {}




-- Run this every 1/30 of a second.
-- WHAT IT DOES:
-- Whenever a living player presses their microphone key, they speak some random Bob chatter, and any living things within 3 WU wake up!
function Triggers.idle()

	-- For each player p in all players
	for p in Players() do
	
		-- If this player is pressing the microphone button AND they aren't dead
		if p.action_flags.microphone_button and not p.dead then
		
			-- Play the sound of Bob Chatter coming from this player
			p.monster:play_sound("bob chatter",0.7)
			
			-- Wake up all monsters within preset radius of this player
			Broadcast_Speech(p)
			
		-- End if player's mic button pressed
		end
		
	-- End for all players
	end
	
-- End function called every 1/30 sec
end



-- Run this if a player gets damage.
-- WHAT IT DOES:
-- Every time a player is damaged (and alive), they will either:
-- make the "Stop shooting me!" sound effect if the damage came from a friend
-- make the "grunt" sound effect if the damage came from anything else
function Triggers.player_damaged(victim, aggressor_player, aggressor_monster, damage_type, damage_amount, projectile)


	-- Firstly, if the victim is still alive...
	if (victim.dead ~= true) then

		-- If a monster caused the damage (not of class nil)...
		if (aggressor_monster ~= nil) then
	
	
			-- If the victim player and the aggressor monster are friends...
			if (MonsterTypes["player"].friends[aggressor_monster.type.class]) then

				-- Play the "Stop Shooting Me!" sound from this player
				victim.monster:play_sound("bob angry",0.7)
				
				-- Wake up all monsters within preset radius of this player
				Broadcast_Speech(victim)

			-- If they aren't friends
			else
		
				-- Play the grunt sound from this player
				victim.monster:play_sound("bob hit",0.7)

				-- Wake up all monsters within preset radius of this player
				Broadcast_Speech(victim)
		
		
			end

		-- If a monster did NOT cause the damage...
		elseif (aggressor_monster == nil) then

			-- Play the grunt sound from this player
			victim.monster:play_sound("bob hit",0.7)
			
			-- Wake up all monsters within preset radius of this player
			Broadcast_Speech(victim)
	
		end
	
	end	


-- End function called if a player gets damage.
end






-- Run this whenever a player kills something.
-- WHAT IT DOES:
-- Every time a player kills a friend, that player will apologize.
-- Every time a player kills an enemy, that player will trash talk.
function Triggers.monster_killed(monster, aggressor_player, projectile)


	--Only run if a player caused the damage (not of class nil)...
	if (aggressor_player ~= nil) then
	
		-- If the player killed a friend...
		if (MonsterTypes["player"].friends[monster.type.class]) then
		
			-- Play the "Apology" sound from this player
			aggressor_player.monster:play_sound("bob apology",0.7)		
		
		-- But if the player killed an enemy...
		else

			-- Play the "Gotcha" sound from this player
			aggressor_player.monster:play_sound("bob trash talk",0.7)
		
		end
		
		-- Wake up all monsters within preset radius of this player
		Broadcast_Speech(aggressor_player)

	end

end







-- Run this void function whenever it is called.
-- WHAT IT DOES:
-- Given an input player object, when called, it will wake up all sleeping monsters within a preset spherical radius of this player.
function Broadcast_Speech(playerObj)


	-- For all existing monsters
	for m in Monsters() do
			
		-- If this monster isn't a player
		if (m.player == nil) then
				
			-- If this monster is not awake and is visible...
			if not (m.active) and (m.visible) then
					
				-- Calculate the 3D distance between this monster and the current player
				m_Dist = math.sqrt( (m.x - playerObj.x)^2 + (m.y - playerObj.y)^2 + (m.z - playerObj.z)^2 )
					
				-- If this distance is less than 5 WU
				if m_Dist < 5 then
					
					-- Wake up all monsters within 5 WU of the player who spoke!
					m.active = true
							
				-- End distance less than 5 WU
				end
					
			-- End if this monster not awake
			end
					
		-- End if this monster not a player
		end
				
	-- End for all monsters
	end


end